SN3218
======

A set of drivers for the SN3218 18-channel PWM LED driver.

To install use (as root):

	python setup.py install

To view a set of examples hook up your SN3218 device and run:

	python sn3218.py

Features:

- Python and Arduino implementations of drivers
- Default gamma correction (overridable per channel)